@@ -11,8 +11,8 @@ from shutil import copy2
 from warnings import warn
 
 from monty.json import MSONable
+from mp_api.client import MPRester
 from pymatgen.core.structure import Structure
-from pymatgen.ext.matproj import MPRester, MPRestError
 from tqdm import tqdm
 
 from lightshow import _get_API_key_from_environ
@@ -20,7 +20,6 @@ from lightshow import pymatgen_utils
 
 
 def _delete_common_strings(old_list_of_strings):
-
     list_of_strings = [str(Path(xx).parent) for xx in old_list_of_strings]
     list_of_names = [str(Path(xx).name) for xx in old_list_of_strings]
 
@@ -39,76 +38,6 @@ def _delete_common_strings(old_list_of_strings):
     ]
 
 
-def _fetch_from_MP(mpr, mpid, metadata_keys):
-    """Uses the provided MPID to fetch the structure data.
-
-    Parameters
-    ----------
-    mpr : pymatgen.ext.matproj.MPRester
-        Interface to the Materials Project REST API.
-    mpid : str
-        The specific mpid to pull.
-    metadata_keys : list of str, optional
-        The Materials Project metadata contains a huge amount of information.
-        If not ``None``, these are the only keys that are kept in the pulled
-        metadata object.
-
-    Returns
-    -------
-    tuple
-        The structure (:class:`pymatgen.core.structure.Structure`) of interest
-        and the specified metadata.
-    """
-
-    metadata = mpr.get_doc(mpid)
-
-    if metadata_keys is not None:
-        metadata = {key: metadata[key] for key in metadata_keys}
-    metadata["downloaded_at"] = datetime.now().strftime("%Y-%m-%d %H:%M:%S")
-
-    # The structure is precisely in the data pulled from get_doc:
-    structure = Structure.from_dict(metadata.pop("structure"))
-
-    return structure, metadata
-
-
-def _from_mpids_list(mpids, api_key, metadata_keys, verbose=True):
-    """Makes one large API call to the Materials Project database and pulls the
-    relevant structural files given a list of Materials Project ID's (mpids).
-
-    Parameters
-    ----------
-    mpids : list of str
-        List of Materials Project IDs to pull.
-    api_key : str, optional
-        Materials Project API key.
-    metadata_keys : bool, optional
-        If True, will only
-    verbose : bool, optional
-        If True, will use tqdm to print a progress bar.
-
-    Returns
-    -------
-    dict
-        A dictionary containing the structures (with keys as the mpids) and
-        metadata (with the same keys).
-    """
-
-    structures = dict()
-    metadatas = dict()
-    with MPRester(api_key) as mpr:
-        for mpid in tqdm(mpids, disable=not verbose):
-            try:
-                structure, metadata = _fetch_from_MP(mpr, mpid, metadata_keys)
-            except MPRestError as error:
-                warn(f"MPRestError pulling mpid={mpid}, error: {error}")
-                continue
-            structures[mpid] = structure.get_primitive_structure()
-            metadatas[mpid] = metadata
-
-    return {"structures": structures, "metadata": metadatas}
-
-
 def _get_api_key(api_key):
     if api_key is None:
         api_key = _get_API_key_from_environ()
@@ -195,119 +124,48 @@ class Database(MSONable):
         return kls
 
     @classmethod
-    def from_materials_project(
-        cls,
-        query,
-        query_type="mpids",
-        api_key=None,
-        metadata_keys=[
-            "created_at",
-            "blessed_tasks",
-            "pseudo_potential",
-            "spacegroup",
-            "_id",
-            "structure",
-            "icsd_ids",
-            "e_above_hull",
-            "formation_energy_per_atom",
-            "band_gap",
-            "diel",
-        ],
-        verbose=True,
-    ):
+    def from_materials_project(cls, **kwargs):
         """Constructs the :class:`.Database` object by pulling structures and
-        metadata directly from the Materials Project. The following query types
-        are allowed:
-
-        * ``query_type == mpids``, the ``query`` argument is simply a list of
-          Materials Project IDs.
-        * ``query_type == patterns``, the ``query`` argument is a list
-          of patterns, e.g. ``[Ti-O, Ti-O-*, Cu-O-*]``.
-        * ``query_type == mp_query``, then the ``query`` argument is
-          just a dict that is passed directly to the ``mpr.query`` method,
-          where ``mpr`` is the MPRester object.
+        metadata directly from the Materials Project. This is a simple
+        passthrough method which utilizes the MPRester.materials.summary.search
+        API of the Materials Project v2 API.
 
         Parameters
         ----------
-        query : list or dict
-            The query itself, the form of which is determined by
-            ``query_type``.
-        query_type : str, optional
-            There are three different types of allowed queries: ``mpids``,
-            ``patterns``, or ``mp_query``. See above for the allowed query
-            types.
-        api_key : str, optional
-            Materials Project API key. If None (not provided), looks for the
-            environment variable ``PMG_API_KEY``.
-        metadata_keys : list, optional
-            The Materials Project metadata contains a huge amount of
-            information. If not ``None``, these are the only keys that are kept
-            in the pulled metadata object.
-        verbose : bool, optional
-            If True, uses the :class:`tqdm` progress bar. Otherwise will
-            silence it.
+        **kwargs
+            Description
+
+        Examples
+        --------
+
+        Deleted Parameters
+        ------------------
+        mpr_query_kwargs : dict
+            Direct passthrough to MPRester.materials.summary.search. See
+            examples below.
+        api_key : None, optional
+            API key which can either be provided directly or is read from
+            the MP_API_KEY environment variable.
 
         Returns
         -------
         Database
-
-        Examples
-        --------
-        Construct a :class:`.Database` via directly pulling certain materials
-        by MPID.
-
-        .. code-block:: python
-
-            database = Database.from_materials_project(["mp-390", "mvc-1115"])
-
-        Construct a :class:`.Database` via pulling all materials consistent
-        with certain patterns. For example, to pull all binary and ternary
-        titanium oxide compounds:
-
-        .. code-block:: python
-
-            database = Database.from_materials_project(
-                ["Ti-O", "Ti-O-*"], query_type="patterns"
-            )
         """
 
-        api_key = _get_api_key(api_key)
+        api_key = _get_api_key(kwargs.get("api_key"))
 
-        # Nothing to do here
-        if query_type == "mpids":
-            mpids = query
+        try:
+            kwargs.pop("api_key")
+        except KeyError:
+            pass
 
-        # Convert the patterns into a list of mpids
-        elif query_type == "patterns":
-            mpids = []
-            with MPRester(api_key) as mpr:
-                for pattern in query:
-                    data = mpr.get_data(pattern, data_type="vasp")
-                    mpids.extend([xx["material_id"] for xx in data])
+        with MPRester(api_key) as mpr:
+            searched = mpr.materials.summary.search(**kwargs)
 
-        # Convert the raw query itself to a list of mpids
-        elif query_type == "mp_query":
-            with MPRester(api_key) as mpr:
-                materials_list = mpr.query(**query)
-            mpids = [xx["material_id"] for xx in materials_list]
+        structures = {s.material_id.string: s.structure for s in searched}
+        metadata = {s.material_id.string: s.dict() for s in searched}
 
-        # Otherwise we error and terminate
-        else:
-            raise ValueError(f"Unknown query {query_type}")
-
-        # Get all of the data as a dictionary
-        data = _from_mpids_list(
-            mpids,
-            api_key,
-            metadata_keys,
-            verbose=verbose,
-        )
-
-        return cls(
-            structures=data["structures"],
-            metadata=data["metadata"],
-            supercells=dict(),
-        )
+        return cls(structures=structures, metadata=metadata, supercells=dict())
 
     def initialize_supercells(self, supercell_cutoff=9.0):
         """Initializes the supercells from the structures pulled from the
@@ -339,6 +197,10 @@ class Database(MSONable):
         # Do the same for the supercells
         for key, supercell in self._supercells.items():
             info = pymatgen_utils.get_inequivalent_site_info(supercell)
+            mapping = pymatgen_utils.get_supercell_indexes_matching_primitive(
+                self._structures[key], supercell, compare=10, r=5.0
+            )
+            info["prim-supercell-mapping"] = mapping
             self._metadata[key]["supercell"] = info
 
         self._inequivalent_sites_initialized = True
@@ -468,6 +330,21 @@ class Database(MSONable):
             if specie == species
         ]
 
+    def _write_unit_cells(self, root, pbar=False):
+        """A helper method for writing the unit cells in POSCAR format. This
+        is convenient as the atom indexes saved as Lightshow runs correspond
+        to this unit cell.
+
+        Parameters
+        ----------
+        root : os.PathLike
+        pbar : bool, optional
+        """
+
+        for key, structure in tqdm(self._structures.items(), disable=not pbar):
+            fname = Path(root) / key / "POSCAR"
+            structure.to(fmt="POSCAR", filename=str(fname))
+
     def write(
         self,
         root,
@@ -475,6 +352,7 @@ class Database(MSONable):
         options=[],
         pbar=True,
         copy_script=None,
+        write_unit_cells=True,
     ):
         """The core method of the :class:`.Database` class. This method will
         write all input files specified in the ``options`` parameter to disk.
@@ -516,7 +394,8 @@ class Database(MSONable):
             spectroscopy) will be skipped. Only calculations that do not
             require absorbing atoms to be specified (e.g. neutral potential
             VASP electronic structure self-consistent procedure) will be
-            performed.
+            performed. Note this can also be ``"all"``, in which case, every
+            atom in the structure will have input files written for it.
         options : list, optional
             A list of :class:`lightshow.parameters._base._BaseParameters`
             objects or derived instances. The choice of options not only
@@ -528,13 +407,19 @@ class Database(MSONable):
         copy_script : os.PathLike
             If not ``None``, will copy the script in the provided path to each
             of the input file locations.
+        write_unit_cells : bool, optional
+            If True, writes the unit cells in the materials directory in
+            POSCAR format. Very useful!
         """
 
         self._setup_preliminary_attributes()
 
         root = str(Path(root).resolve())  # Get absolute path
 
-        if not isinstance(absorbing_atoms, list):
+        _write_all_atoms = False
+        if absorbing_atoms == "all":
+            _write_all_atoms = True
+        elif not isinstance(absorbing_atoms, list):
             absorbing_atoms = [absorbing_atoms]
 
         writer_metadata = {
@@ -553,25 +438,29 @@ class Database(MSONable):
         writer_metadata_path = root / Path("writer_metadata.json")
 
         for key, supercell in tqdm(self._supercells.items(), disable=not pbar):
+            primitive_cell = self._structures[key]
+            primitive_info = self._metadata[key]["primitive"]
+            supercell_info = self._metadata[key]["supercell"]
+            prim_to_sc_index_mapping = supercell_info["prim-supercell-mapping"]
+
+            if _write_all_atoms:
+                absorbing_atoms = list(
+                    set([s.specie.symbol for s in supercell])
+                )
 
             for absorbing_atom in absorbing_atoms:
-
-                primitive_info = self._metadata[key]["primitive"]
-                supercell_info = self._metadata[key]["supercell"]
+                # Gracefully skip any atoms that are not present in the
+                # structure
+                if not pymatgen_utils.atom_in_structure(
+                    absorbing_atom, supercell
+                ):
+                    continue
 
                 # If inequiv is None, that means that the absorbing_atom was not
                 # specified (absorbing_atom is None)
                 inequiv = self._get_site_indexes_matching_atom(
                     primitive_info, absorbing_atom
                 )
-                inequiv_sc = self._get_site_indexes_matching_atom(
-                    supercell_info, absorbing_atom
-                )
-
-                if inequiv_sc is not None and inequiv is not None:
-                    index_mapping = {k: v for k, v in zip(inequiv, inequiv_sc)}
-                else:
-                    index_mapping = None
 
                 # If the for VASP and XSpectra calculations, use supercell;
                 # otherwise, use unit cell structure
@@ -580,9 +469,9 @@ class Database(MSONable):
                 # if no, ignore them
                 kwargs = {
                     "structure_sc": supercell,
-                    "structure_uc": self._structures[key],
+                    "structure_uc": primitive_cell,
                     "sites": inequiv,
-                    "index_mapping": index_mapping,
+                    "index_mapping": prim_to_sc_index_mapping,
                 }
                 if key in self._metadata.keys():
                     if (
@@ -603,6 +492,9 @@ class Database(MSONable):
                         for p in status["paths"]:
                             copy2(copy_script, p)
 
+        if write_unit_cells:
+            self._write_unit_cells(root, pbar=pbar)
+
         # Save a metadata file (not a serialized version of this class) to
         # disk along with the input files
         with open(writer_metadata_path, "w") as outfile:
