@@ -515,7 +515,6 @@ class PotcarConstructor(MSONable):
 
     @lru_cache(256)
     def _get_element_lines(self, element):
-
         # Get the element directory using the element as a key
         assert isinstance(element, str)
         element_dir = self._element_mapping[element]
@@ -623,7 +622,7 @@ class Poscar(pmgPoscar):
         target_directory,
         site_index=None,
         check_atom_type=None,
-        significant_figures=8,
+        significant_figures=16,
     ):
         """Writes the VASP POSCAR file for the specified ``site_index``.
 
@@ -665,7 +664,7 @@ class Poscar(pmgPoscar):
             return self.site_symbols
 
         # Get the default lines for the POSCAR file
-        lines = self.get_string(significant_figures=significant_figures).split(
+        lines = self.get_str(significant_figures=significant_figures).split(
             "\n"
         )
 
@@ -773,7 +772,6 @@ class VASPParameters(MSONable, _BaseParameters):
         force_spin_unpolarized=False,
         name="VASP",
     ):
-
         if "NBANDS" in incar.keys():
             if incar["NBANDS"] is None and nbands is None:
                 raise ValueError(
